import store from '@/store'
import apiBaseConfig from '@/config/index.js'

function httpBaseUrl() {
	// #ifdef MP-WEIXIN
	return '/dev-api'
	// #endif
}

function switchMethod(method) {
	let header = {};
	switch (method) {
		case 'POST':
			header = {
				// 'Content-Type': 'application/x-www-form-urlencoded;charset=UTF-8',
				'Content-Type': 'application/json;charset=UTF-8',
			}
			break;
		case 'GET':
			header = {
				'Content-Type': 'application/json;charset=UTF-8',
			}
			break;
		case 'PUT':
			header = {
				'Content-Type': 'application/json;charset=UTF-8',
			}
			break;
	}
	return header
}

/**
 * url        接口地址
 * params     参数
 * method     请求方式，必须全大写
 * isToken    请求头是否设置token，默认true
 **/
const ApiHttp = (url, params, method, isToken = true) => {
	let header = {},
		token = store.state.login.token || null;
	header = switchMethod(method)
	if (isToken) {
		header = {
			...header,
			'Authorization': `Bearer ${token}`
		}
	}
	return new Promise((resolve, reject) => {
		// uni.showLoading({
		// 	title: '加载中...',
		// 	mask: true,
		// });
		uni.request({
			url: `${apiBaseConfig.domain}${url}`,
			method,
			data: params,
			header,
			success: (res) => {
				const {
					data
				} = res;
				const {
					code,
					msg
				} = data;
				if (code === 200) {
					resolve(data);
				}else if(code === 701){
					resolve(data);
				} else if (code === 401) {
					uni.showToast({
						title: msg || 'token过期',
						icon: "none"
					})
					let tyim = setInterval(()=>{
						clearInterval(tyim)
						// 清楚缓存
						uni.clearStorageSync();
						uni.reLaunch({
							url: `/pages/login/index`
						})
					},1200)
				} else {
					uni.showToast({
						title: msg || '系统内部错误',
						icon: "none"
					})
					// uni.clearStorageSync();
					// store.dispatch('loginOut')

				}
			},
			fail: (err) => {
				console.log(err, 'pppppppppppp')
				uni.showToast({
					title: err.errMsg,
					icon: "none"
				})
				reject(err)
			},
			complete: () => {
				// uni.hideLoading();
			}
		})
	})
}

export {
	ApiHttp
}
